@@ -2,7 +2,7 @@
 
 package Tcl::pTk::HList;
 
-our ($VERSION) = ('0.83');
+our ($VERSION) = ('0.84');
 
 @Tcl::pTk::HList::ISA = (Tcl::pTk::Widget);
 
@@ -166,7 +166,7 @@ sub info{
 }
 
  
-# Overriden version of info that handles getting -data storage
+# Overriden version of info that handles getting -data storage and -window itemtypes
 sub entrycget{
         my $self   = shift;
         my $item   = shift;
@@ -176,6 +176,10 @@ sub entrycget{
                 my $HListdata = $self->{_HListdata} || {};
                 return $HListdata->{$item};
         }
+        if( $option eq '-window'){
+                my $window = $self->SUPER::entrycget($item, $option);
+                return $self->interp->widget($window);
+        }
         
         return $self->SUPER::entrycget($item, $option, @_);
 }
